<!-- PROJECT LOGO -->
<br />
<p align="center">
  <h2 align="center">descriptools</h2>
  <p align="center">
    A gpu-based toolbox for terrain descriptor calculation/delineation.
    <br />
    ·
    <a href="https://github.com/github_username/repo_name/issues">Report Bug</a>
    ·
    <a href="https://github.com/github_username/repo_name/issues">Request Feature</a>
  </p>
</p>
<br />



<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>


<!-- ABOUT THE PROJECT -->
## About The Project
Terrain descriptors present information of the earth surface and its relationship with water movement.
This toolbox was devised to reduce calculation time of these descriptors with GPU parallelization. As well as functions to produce flood map via linear binary classification. </br>
This toolbox was made for reviewing process of Computer and Geosciences journal for the manuscript entitled: <b>Parallelized geomorphic descriptors for flood-prone areas delineation</b>



### Built With

* [Python](https://www.python.org/)
* [NumPy](https://numpy.org/)
* [Numba](https://numba.pydata.org/)



<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple steps.



### PIP
You can install descriptools using pip:
   ```sh
   pip install descriptools
   ```


<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.

<!-- CONTACT -->
## Contact

Authors: José Vinícius Boinf de Souza and Pedro Luiz Borges Chaffe

Developer: José Vinícius Boing de Souza

Contact address: joseboing@gmail.com

Project Link: [https://github.com/JVBSouza/descriptools](https://github.com/JVBSouza/descriptools)